diff --git a/CHANGES.md b/CHANGES.md
index 1448d53a07..9a41f3c4ef 100644
--- a/CHANGES.md
+++ b/CHANGES.md
@@ -29,6 +29,10 @@ SDK API changes ⚠️:
Build 🧱:
- Some dependencies have been upgraded (coroutine, recyclerView, appCompat, core-ktx, firebase-messaging)
+ - Buildkite:
+ New pipeline location: https://github.com/matrix-org/pipelines/blob/master/element-android/pipeline.yml
+ New build location: https://buildkite.com/matrix-dot-org/element-android
+
Other changes:
- Use File extension functions to make code more concise (#1996)
diff --git a/README.md b/README.md
index 9f31e83ef6..64c6c9d04d 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-[![Buildkite](https://badge.buildkite.com/657d3db27364448d69d54f66c690f7788bc6aa80a7628e37f3.svg?branch=develop)](https://buildkite.com/matrix-dot-org/riotx-android/builds?branch=develop)
+[![Buildkite](https://badge.buildkite.com/ad0065c1b70f557cd3b1d3d68f9c2154010f83c4d6f71706a9.svg?branch=develop)](https://buildkite.com/matrix-dot-org/element-android/builds?branch=develop)
[![Weblate](https://translate.riot.im/widgets/element-android/-/svg-badge.svg)](https://translate.riot.im/engage/element-android/?utm_source=widget)
[![Element Android Matrix room #element-android:matrix.org](https://img.shields.io/matrix/element-android:matrix.org.svg?label=%23element-android:matrix.org&logo=matrix&server_fqdn=matrix.org)](https://matrix.to/#/#element-android:matrix.org)
[![Quality Gate](https://sonarcloud.io/api/project_badges/measure?project=im.vector.app.android&metric=alert_status)](https://sonarcloud.io/dashboard?id=im.vector.app.android)
@@ -14,7 +14,7 @@ It is a total rewrite of [Riot-Android](https://github.com/vector-im/riot-androi
[](https://play.google.com/store/apps/details?id=im.vector.app)
[](https://f-droid.org/app/im.vector.app)
-Nightly build: [![Buildkite](https://badge.buildkite.com/657d3db27364448d69d54f66c690f7788bc6aa80a7628e37f3.svg?branch=develop)](https://buildkite.com/matrix-dot-org/riotx-android/builds?branch=develop)
+Nightly build: [![Buildkite](https://badge.buildkite.com/ad0065c1b70f557cd3b1d3d68f9c2154010f83c4d6f71706a9.svg?branch=develop)](https://buildkite.com/matrix-dot-org/element-android/builds?branch=develop)
# New Android SDK
diff --git a/build.gradle b/build.gradle
index 061dd73a40..f06d1859b5 100644
--- a/build.gradle
+++ b/build.gradle
@@ -87,7 +87,7 @@ sonarqube {
property "sonar.projectVersion", project(":vector").android.defaultConfig.versionName
property "sonar.sourceEncoding", "UTF-8"
property "sonar.links.homepage", "https://github.com/vector-im/element-android/"
- property "sonar.links.ci", "https://buildkite.com/matrix-dot-org/riotx-android"
+ property "sonar.links.ci", "https://buildkite.com/matrix-dot-org/element-android"
property "sonar.links.scm", "https://github.com/vector-im/element-android/"
property "sonar.links.issue", "https://github.com/vector-im/element-android/issues"
property "sonar.organization", "new_vector_ltd_organization"
diff --git a/tools/release/download_buildkite_artifacts.py b/tools/release/download_buildkite_artifacts.py
index ef4251a14f..4439c2fb8c 100755
--- a/tools/release/download_buildkite_artifacts.py
+++ b/tools/release/download_buildkite_artifacts.py
@@ -25,9 +25,9 @@ import requests
# This script downloads artifacts from buildkite.
# Ref: https://buildkite.com/docs/apis/rest-api/artifacts#download-an-artifact
# Those two variable are specific to the RiotX project
ORG_SLUG = "matrix-dot-org"
-PIPELINE_SLUG = "riotx-android"
+PIPELINE_SLUG = "element-android"
### Arguments
@@ -25,9 +25,9 @@ import requests
# This script downloads artifacts from buildkite.
# Ref: https://buildkite.com/docs/apis/rest-api/artifacts#download-an-artifact
-# Those two variable are specific to the RiotX project
+# Those two variables are specific to the Element Android project
ORG_SLUG = "matrix-dot-org"